@@ -270,27 +270,50 @@ class StorageInputs(object):
     window: t.Optional[int] = opt_field()
     step: t.Optional[int] = opt_field()
 
+dam_energy_prices = t.List[float]
 
+@dataclass_json
+@dataclass
+class AncillaryEnergyPrices(object):
+    dam: dam_energy_prices
+    rtm: t.List[float]
 
 @dataclass_json
 @dataclass
 class StorageModel(object):
     storage_inputs: StorageInputs
-    energy_prices: t.List[float]
+    energy_prices: t.Union[AncillaryEnergyPrices,dam_energy_prices]
+
+@dataclass_json
+@dataclass
+class Utilization(object):
+    actual: float
+    lower: float
+    upper: float
+
+@dataclass_json
+@dataclass
+class ReserveMarket(object):
+    price: t.List[float]
+    offer_cap: float
+    utilization: Utilization
+
+@dataclass_json
+@dataclass
+class AncillaryUpMarkets(object):
+    rrs: t.Optional[ReserveMarket] = opt_field()
+    reg_up: t.Optional[ReserveMarket] = opt_field()
+
+@dataclass_json
+@dataclass
+class AncillaryDownMarket(object):
+    reg_down: ReserveMarket
 
 @dataclass_json
 @dataclass
 class AncillaryMarkets(object):
-    rrs_capacity_factor: t.Optional[float]
-    reg_up_capacity_factor: t.Optional[float]
-    reg_down_capacity_factor: t.Optional[float]
-    rrs_utilization: t.Optional[float]
-    reg_up_utilization: t.Optional[float]
-    reg_down_utilization: t.Optional[float]
-    rrs_prices: t.Optional[t.List[float]]
-    reg_up_prices: t.Optional[t.List[float]]
-    reg_down_prices: t.Optional[t.List[float]]
-    reserve_settlement_prices: t.List[float]
+    up: t.Optional[AncillaryUpMarkets] = opt_field()
+    down: t.Optional[AncillaryDownMarket] = opt_field()
 
 @dataclass_json
 @dataclass
@@ -311,8 +334,9 @@ class PVStorageModel(object):
     storage_coupling: StorageCoupling = field(metadata=StorageCoupling.__metadata__)
     pv_inputs: PVModel
     storage_inputs: StorageInputs
-    energy_prices: t.List[float]
+    energy_prices: t.Union[AncillaryEnergyPrices, dam_energy_prices]
     enable_grid_charge_year: t.Optional[int] = opt_field()
+    ancillary_markets: t.Optional[AncillaryMarkets] = opt_field()
 
 
 @string_enum
